Bodhi — bodhi 3.1.0 documentation

# Bodhi

Bodhi is designed to democratize the package update testing and release process for RPM based Linux distributions. It provides an interface for developers to propose updates to a distribution, and an interface for testers to leave feedback about updates through a +1/-1 karma system.

Bodhi’s main features are:

- Provides an interface for developers and release engineers to manage pushing out package updates for multiple distribution versions.
- Generates pre-release test repositories for end users and testers to install proposed updates.
- Gives testers an interface to leave feedback about package updates, leading to higher quality package updates.
- Announces the arrival of new packages entering the collection.
- Publishes end-user release notes known as errata.
- Generates yum repositories.
- Queries ResultsDB for automated test results and displays them on updates.

## User Guide

- Update states
  - Pending
  - Testing
  - Testing/Batched
  - Testing/Stable
  - Stable
  - Obsolete
  - Revoked
  - Unpushed
- Man pages
  - bodhi
  - bodhi-approve-testing
  - bodhi-check-policies
  - bodhi-clean-old-mashes
  - bodhi-dequeue-stable
  - bodhi-monitor-composes
  - bodhi-push
  - initialize_bodhi_db

- Release notes

## API Guide

- Bodhi Server APIs
  - fedmsg API
  - REST API
- Python bindings
  - bodhi.client.bindings

## Contributor Guide

- Developer documentation
  - Contribution guidelines
  - Easy Fix
  - CI Tests
  - Create a Bodhi development environment
- Vagrant
  - Quick tips about the Bodhi Vagrant environment
- Virtualenv
  - Dependencies
  - Setup virtualenvwrapper
  - Set PYTHONPATH
  - Clone the source
  - Bootstrap the virtualenv
  - Setting up
  - Create the development.ini file
  - Run the test suite
  - Import the bodhi2 database
  - Adjust database configuration in development.ini file
  - Upgrade the database
  - Run the web app
  - Setup the postgresql server
- Database models
  - bodhi.server.models
  - Database Schema

## Admin Guide

- Administration
  - System Requirements
  - Configuration

## Community

Bodhi is maintained by the Fedora Project and its source code and issue tracker are on GitHub. There is a mailing list and an IRC channel on FreeNode, `#bodhi` for discussion about Bodhi. Fedora runs a production instance and staging instance. Online documentation is available on both production and staging.